@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -70,7 +70,7 @@ __all__ = ("BatchClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -83,7 +83,7 @@ class Exceptions:
 
 class BatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html)
     """
 
@@ -99,7 +99,7 @@ class BatchClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#can_paginate)
         """
 
@@ -107,7 +107,7 @@ class BatchClient(BaseClient):
         """
         Cancels a job in an Batch job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#cancel_job)
         """
 
@@ -119,12 +119,12 @@ class BatchClient(BaseClient):
         state: CEStateType = None,
         computeResources: "ComputeResourceTypeDef" = None,
         serviceRole: str = None,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> CreateComputeEnvironmentResponseTypeDef:
         """
         Creates an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.create_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.create_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_compute_environment)
         """
 
@@ -133,14 +133,14 @@ class BatchClient(BaseClient):
         *,
         jobQueueName: str,
         priority: int,
-        computeEnvironmentOrder: List["ComputeEnvironmentOrderTypeDef"],
+        computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"],
         state: JQStateType = None,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> CreateJobQueueResponseTypeDef:
         """
         Creates an Batch job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.create_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.create_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_job_queue)
         """
 
@@ -148,7 +148,7 @@ class BatchClient(BaseClient):
         """
         Deletes an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.delete_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.delete_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_compute_environment)
         """
 
@@ -156,7 +156,7 @@ class BatchClient(BaseClient):
         """
         Deletes the specified job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.delete_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.delete_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_job_queue)
         """
 
@@ -164,28 +164,28 @@ class BatchClient(BaseClient):
         """
         Deregisters an Batch job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.deregister_job_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.deregister_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#deregister_job_definition)
         """
 
     def describe_compute_environments(
         self,
         *,
-        computeEnvironments: List[str] = None,
+        computeEnvironments: Sequence[str] = None,
         maxResults: int = None,
         nextToken: str = None
     ) -> DescribeComputeEnvironmentsResponseTypeDef:
         """
         Describes one or more of your compute environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.describe_compute_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.describe_compute_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_compute_environments)
         """
 
     def describe_job_definitions(
         self,
         *,
-        jobDefinitions: List[str] = None,
+        jobDefinitions: Sequence[str] = None,
         maxResults: int = None,
         jobDefinitionName: str = None,
         status: str = None,
@@ -194,39 +194,39 @@ class BatchClient(BaseClient):
         """
         Describes a list of job definitions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.describe_job_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.describe_job_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_definitions)
         """
 
     def describe_job_queues(
-        self, *, jobQueues: List[str] = None, maxResults: int = None, nextToken: str = None
+        self, *, jobQueues: Sequence[str] = None, maxResults: int = None, nextToken: str = None
     ) -> DescribeJobQueuesResponseTypeDef:
         """
         Describes one or more of your job queues.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.describe_job_queues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.describe_job_queues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_queues)
         """
 
-    def describe_jobs(self, *, jobs: List[str]) -> DescribeJobsResponseTypeDef:
+    def describe_jobs(self, *, jobs: Sequence[str]) -> DescribeJobsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.describe_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.describe_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_jobs)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#generate_presigned_url)
         """
 
@@ -239,12 +239,12 @@ class BatchClient(BaseClient):
         jobStatus: JobStatusType = None,
         maxResults: int = None,
         nextToken: str = None,
-        filters: List["KeyValuesPairTypeDef"] = None
+        filters: Sequence["KeyValuesPairTypeDef"] = None
     ) -> ListJobsResponseTypeDef:
         """
         Returns a list of Batch jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_jobs)
         """
 
@@ -252,7 +252,7 @@ class BatchClient(BaseClient):
         """
         Lists the tags for an Batch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_tags_for_resource)
         """
 
@@ -261,19 +261,19 @@ class BatchClient(BaseClient):
         *,
         jobDefinitionName: str,
         type: JobDefinitionTypeType,
-        parameters: Dict[str, str] = None,
+        parameters: Mapping[str, str] = None,
         containerProperties: "ContainerPropertiesTypeDef" = None,
         nodeProperties: "NodePropertiesTypeDef" = None,
         retryStrategy: "RetryStrategyTypeDef" = None,
         propagateTags: bool = None,
         timeout: "JobTimeoutTypeDef" = None,
-        tags: Dict[str, str] = None,
-        platformCapabilities: List[PlatformCapabilityType] = None
+        tags: Mapping[str, str] = None,
+        platformCapabilities: Sequence[PlatformCapabilityType] = None
     ) -> RegisterJobDefinitionResponseTypeDef:
         """
         Registers an Batch job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.register_job_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.register_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#register_job_definition)
         """
 
@@ -284,27 +284,27 @@ class BatchClient(BaseClient):
         jobQueue: str,
         jobDefinition: str,
         arrayProperties: "ArrayPropertiesTypeDef" = None,
-        dependsOn: List["JobDependencyTypeDef"] = None,
-        parameters: Dict[str, str] = None,
+        dependsOn: Sequence["JobDependencyTypeDef"] = None,
+        parameters: Mapping[str, str] = None,
         containerOverrides: "ContainerOverridesTypeDef" = None,
         nodeOverrides: "NodeOverridesTypeDef" = None,
         retryStrategy: "RetryStrategyTypeDef" = None,
         propagateTags: bool = None,
         timeout: "JobTimeoutTypeDef" = None,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> SubmitJobResponseTypeDef:
         """
         Submits an Batch job from a job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.submit_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.submit_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#submit_job)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Associates the specified tags to a resource with the specified `resourceArn`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#tag_resource)
         """
 
@@ -312,15 +312,15 @@ class BatchClient(BaseClient):
         """
         Terminates a job in a job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.terminate_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.terminate_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#terminate_job)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Deletes specified tags from an Batch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#untag_resource)
         """
 
@@ -335,7 +335,7 @@ class BatchClient(BaseClient):
         """
         Updates an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.update_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.update_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_compute_environment)
         """
 
@@ -345,12 +345,12 @@ class BatchClient(BaseClient):
         jobQueue: str,
         state: JQStateType = None,
         priority: int = None,
-        computeEnvironmentOrder: List["ComputeEnvironmentOrderTypeDef"] = None
+        computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"] = None
     ) -> UpdateJobQueueResponseTypeDef:
         """
         Updates a job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Client.update_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Client.update_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_job_queue)
         """
 
@@ -359,7 +359,7 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_compute_environments"]
     ) -> DescribeComputeEnvironmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describecomputeenvironmentspaginator)
         """
 
@@ -368,7 +368,7 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_job_definitions"]
     ) -> DescribeJobDefinitionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobdefinitionspaginator)
         """
 
@@ -377,13 +377,13 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_job_queues"]
     ) -> DescribeJobQueuesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobqueuespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/batch.html#Batch.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/batch.html#Batch.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#listjobspaginator)
         """
